Package: pairedGSEA
Title: Paired DGE and DGS analysis for gene set enrichment analysis
Version: 1.12.0
Authors@R: c(
    person(given = "Søren Helweg",
        family = "Dam",
        email = "sohdam@dtu.dk",
        role = c("cre", "aut"),
        comment = c(ORCID = "0000-0002-9895-0930")),
    person(given = "Lars Rønn",
        family = "Olsen",
        email = "lronn@dtu.dk",
        role = "aut",
        comment = c(ORCID = "0000-0002-6725-7850")),
    person(given = "Kristoffer",
        family = "Vitting-Seerup",
        email = "krivi@dtu.dk",
        role = "aut",
        comment = c(ORCID = "0000-0002-6450-0608"))
        )
Description: pairedGSEA makes it simple to run a paired Differential
        Gene Expression (DGE) and Differencital Gene Splicing (DGS)
        analysis. The package allows you to store intermediate results
        for further investiation, if desired. pairedGSEA comes with a
        wrapper function for running an Over-Representation Analysis
        (ORA) and functionalities for plotting the results.
License: MIT + file LICENSE
Imports: DESeq2, DEXSeq, limma, fgsea, msigdbr, sva,
        SummarizedExperiment, S4Vectors, BiocParallel, ggplot2,
        aggregation, stats, utils, methods, showtext
Suggests: writexl, readxl, readr, rhdf5, plotly, testthat (>= 3.0.0),
        knitr, rmarkdown, BiocStyle, covr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2
VignetteBuilder: knitr
biocViews: DifferentialExpression, AlternativeSplicing,
        DifferentialSplicing, GeneExpression, ImmunoOncology,
        GeneSetEnrichment, Pathways, RNASeq, Software, Transcription,
URL: https://github.com/shdam/pairedGSEA
BugReports: https://github.com/shdam/pairedGSEA/issues
Depends: R (>= 4.4.0)
Config/pak/sysreqs: libfreetype6-dev libbz2-dev libicu-dev liblzma-dev
        libpng-dev libxml2-dev libssl-dev xz-utils zlib1g-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 13:00:39 UTC
RemoteUrl: https://github.com/bioc/pairedGSEA
RemoteRef: RELEASE_3_23
RemoteSha: 79ba22dab9601074e7008f83921e3a05de262d66
NeedsCompilation: no
Packaged: 2026-04-29 23:45:43 UTC; root
Author: Søren Helweg Dam [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-9895-0930>),
  Lars Rønn Olsen [aut] (ORCID: <https://orcid.org/0000-0002-6725-7850>),
  Kristoffer Vitting-Seerup [aut] (ORCID:
    <https://orcid.org/0000-0002-6450-0608>)
Maintainer: Søren Helweg Dam <sohdam@dtu.dk>
Built: R 4.6.0; ; 2026-04-30 01:17:18 UTC; unix
