# Generated by roxygen2: do not edit by hand

export(paired_diff)
export(paired_ora)
export(plot_ora)
export(prepare_msigdb)
import(BiocParallel)
import(DESeq2)
import(DEXSeq)
import(SummarizedExperiment)
import(fgsea)
importFrom(S4Vectors,DataFrame)
importFrom(S4Vectors,as.data.frame)
importFrom(S4Vectors,complete.cases)
importFrom(S4Vectors,split)
importFrom(SummarizedExperiment,colData)
importFrom(aggregation,lancaster)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,guide_legend)
importFrom(ggplot2,guides)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_shape_manual)
importFrom(limma,diffSplice)
importFrom(limma,eBayes)
importFrom(limma,is.fullrank)
importFrom(limma,lmFit)
importFrom(limma,topSplice)
importFrom(limma,topTable)
importFrom(limma,voom)
importFrom(methods,is)
importFrom(msigdbr,msigdbr)
importFrom(showtext,showtext_auto)
importFrom(stats,cor)
importFrom(stats,formula)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,weighted.mean)
importFrom(sva,sva)
importFrom(utils,write.csv)
importFrom(utils,write.table)
